/*
  Test code for the LTE shield.
  Pete Lewis 11/7/2018

  Modifed by Wes Furuya 1/7/2019

  You will need this library installed into your Arduino for this to comile:
  https://github.com/sparkfun/SparkFun_LTE_Shield_Arduino_Library

  Initialize cell module via AT SerialMonitor commands.
  Check for Sim card status via AT SerialMonitor commands.
  Check for network roaming status - to verify onboard antennae is working.

*/

#include <SparkFun_LTE_Shield_Arduino_Library.h>

// We need to pass a SerialMonitor or SoftwareSerialMonitor object to the LTE Shield
// library. Below creates a SoftwareSerialMonitor object on the standard LTE
// Shield RX/TX pins:
SoftwareSerial lteSerial(8, 9); //TX then RX

// Create a LTE_Shield object to be used throughout the sketch:
LTE_Shield lte;

int failures = 0; //Number of failures by the main test routine

// To support multiple architectures, SerialMonitor ports are abstracted here.
// By default, they'll support AVR's like the Arduino Uno and Redboard
// For example, on a SAMD21 board SerialMonitorMonitor can be changed to SerialMonitorUSB
// and LTEShieldSerialMonitor can be set to SerialMonitor1 (hardware SerialMonitor port on 0/1)
#define SerialMonitor Serial
#define LTEShieldSerial lteSerial

// Map registration status messages to more readable strings
String registrationString[] = {
  "Not registered",                         // 0
  "Registered, home",                       // 1
  "Searching for operator",                 // 2
  "Registration denied",                    // 3
  "Registration unknown",                   // 4
  "Registrered, roaming",                   // 5
  "Registered, home (SMS only)",            // 6
  "Registered, roaming (SMS only)",         // 7
  "Registered, home, CSFB not preferred",   // 8
  "Registered, roaming, CSFB not prefered"  // 9
};

// Network operator can be set to either:
// MNO_SW_DEFAULT -- DEFAULT
// MNO_ATT -- AT&T 
// MNO_VERIZON -- Verizon
// MNO_TELSTRA -- Telstra
// MNO_TMO -- T-Mobile
const mobile_network_operator_t MOBILE_NETWORK_OPERATOR = MNO_SW_DEFAULT;
const String MOBILE_NETWORK_STRINGS[] = {"Default", "SIM_ICCD", "AT&T", "VERIZON", 
  "TELSTRA", "T-Mobile", "CT"};

// APN -- Access Point Name. Gateway between GPRS MNO
// and another computer network. E.g. "hologram
const String APN = "hologram";

// This defines the size of the ops struct array. Be careful making
// this much bigger than ~5 on an Arduino Uno. To narrow the operator
// list, set MOBILE_NETWORK_OPERATOR to AT&T, Verizeon etc. instead
// of MNO_SW_DEFAULT.
#define MAX_OPERATORS 5

#define DEBUG_PASSTHROUGH_ENABLED

void setup()
{
  int opsAvailable;
  struct operator_stats ops[MAX_OPERATORS];
  String currentOperator = "";
  bool newConnection = true;

  SerialMonitor.begin(9600);
  while (!SerialMonitor) ; // For boards with built-in USB
  
  SerialMonitor.println(F("LTE Shield Test\n\r"));
  SerialMonitor.println(F("Initializing... This can take up to 20 seconds."));
  
  // Call lte.begin and pass it your Serial/SoftwareSerial object to 
  // communicate with the LTE Shield.
  // Note: If you're using an Arduino with a dedicated hardware serial
  // port, you may instead slide "Serial" into this begin call.
  if ( lte.begin(LTEShieldSerial, 9600) ) {
    SerialMonitor.println(F("PASS!\r\n"));
  } else {
    SerialMonitor.println("Initialization FAILED. (check your swtich is set to SOFT");
    SerialMonitor.println("Manually power-on (hold POWER for 3 seconds)");
    while(1) ;
  }


  // SIM Card Check
  SerialMonitor.println(F("Getting device/SIM info:"));
  // Print device information:
  String imei, imsi, ccid;
  // IMEI: International Mobile Equipment Identity -- Unique number to identify phone
  imei = lte.imei();
  SerialMonitor.println("IMEI: " + imei);
  // IMSI: International Mobile Subscriber Identity -- Unique number to identify
  // user of a cellular network.
  imsi = lte.imsi();
  if (imsi.length() < 10) {
    SerialMonitor.println(F("IMSI ERROR- Is your SIM card inserted?"));
  } else {
    SerialMonitor.println("IMSI: " + imsi);
  }
  //ICCID: Integrated circuit card identifier -- Unique SIM card SerialMonitor number.
  ccid = lte.ccid();
  if (imsi.length() < 10) {
    SerialMonitor.println(F("CCID ERROR- Is your SIM card inserted?"));
  } else {
    SerialMonitor.println("ICCID: " + ccid);
  }

  // Registration Status
  // Usually the first time you check registration, it has not switched to roaming yet.
  int timeout = 10; // # tries and you're out.
  int regStatus;
  int rssi;
  while (timeout)
  {
    regStatus = lte.registration();
    rssi = lte.rssi();
    Serial.print("Registration check ");
    Serial.print(", RegStatus:");
    Serial.print(regStatus);
    Serial.print(", RSSI:");
    Serial.println(rssi);
    if ((regStatus >= 0) && (regStatus <= 9)) {
      Serial.println("Network registration: " + registrationString[regStatus]);
    }
    if (regStatus == 5) {
      Serial.println(F("SUCCESS!"));
      break;
    }
    delay(1000);
    timeout--;
    if (timeout == 0) {
      Serial.println("Timed out on registration check.");
      failures++;
    }
  }


}

void loop()
{
  
}

